==> homesitemaker-v0.4.5.tar.gz: homesitemaker/includes/languages/catalan/homesite-includes-dbwa.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004 Marcos Martinez Jimenez

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/

//---------- ./homesite/includes/dbwa.php ----------

$TEXT001="El nick seleccionat ja existeix!!!<br>".
         "Si us plau, selecciona un de diferent";

$TEXT002="Els passwords no son iguals";

$TEXT003="El password ha de tenir mes de 8 car&agrave;cters i menys de 16.";

$TEXT004="El Nick no pot tenir mes de 16 car&agrave;cters de logitud.<br>".
         "Si us play, selecciona un de diferent.";

$TEXT005="Intenta-hoo un altre vegada!";
$TEXT006="El camp T&iacute;tol &eacute;s obligatiori.";
$TEXT007="Si selecciones la opci&oacute;:<p><i>Nom&eacute;s una llista d'usuaris enregistrats</i></p>".
         "Llavors has de seleccionar, com a m&iacute;m, un usuari de la llista.";

$TEXT008="No pots seleccionar una llista d'usuaris enregistrats<br>".
	 "si no selecciones tamb&eacute; la opci&oacute; <i>Nom&eacute;s una llista d'usuaris enregistrats </i>option";

$TEXT009="L'&agrave;lbum seleccionat ha sigut eliminat.";
$TEXT010="tamany";
$TEXT011="ha sigut esborrat";
$TEXT012="El directori";
$TEXT013="ha sigut esborrat";
$TEXT014="Totes les entradas de la base de dades relatives a aquesta informaci&oacute; han sigut eliminades";

$TEXT015="La teva not&iacute;cia a sigut emmagatzemada".
         "Si tot es correcte, ser&agrave; publicada per un dels nostres editors tan aviat como sigui possible.";

$TEXT016="L'usuari s'ha creat correctament. Ara ja pots validar-te com usuari registrat";
$TEXT017="La teva petici&oacute; ha sigut processada.";

$TEXT018="Usuari no v&agrave;lid! No pots realitzar aquesta operaci&oacute;.<br>".
         "Potser no hauries d'estar aqu&iacute;!!!<br>".
         "Aquesta situaci&oacute; ha sigut reportada a l'administrador del sistema.";
$TEXT019="Feeds RSS 2.0 actualitzats !";
$TEXT020="Substituit per ->";

$SUBMIT_NEW="Enviar";     // IMPORTANT !! Put the same string you putted $TEXT001 in homesite-news 
$SAVE="Guardar";          // IMPORTANT !! Put the same string you putted $TEXT023 in homesite-news
$PREVIEW="Previsualitzar"; // IMPORTANT !! Put the same string you putted $TEXT025 in homesite-news
$PUBLISH="Publicar";      // IMPORTANT !! Put the same string you putted $TEXT026 and $IEBM002 like 
                          // in homesite-news and homesite-info 


?>

==> homesitemaker-v0.4.7.tar.gz: homesitemaker/includes/languages/catalan/homesite-includes-dbwa.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004 Marcos Martinez Jimenez

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/

//---------- ./homesite/includes/dbwa.php ----------

$TEXT001="El nick seleccionat ja existeix!!!<br>".
         "Si us plau, selecciona un de diferent";

$TEXT002="Els passwords no son iguals";

$TEXT003="El password ha de tenir mes de 8 car&agrave;cters i menys de 16.";

$TEXT004="El Nick no pot tenir mes de 16 car&agrave;cters de logitud.<br>".
         "Si us play, selecciona un de diferent.";

$TEXT005="Intenta-hoo un altre vegada!";
$TEXT006="El camp T&iacute;tol &eacute;s obligatiori.";
$TEXT007="Si selecciones la opci&oacute;:<p><i>Nom&eacute;s una llista d'usuaris enregistrats</i></p>".
         "Llavors has de seleccionar, com a m&iacute;m, un usuari de la llista.";

$TEXT008="No pots seleccionar una llista d'usuaris enregistrats<br>".
	 "si no selecciones tamb&eacute; la opci&oacute; <i>Nom&eacute;s una llista d'usuaris enregistrats </i>option";

$TEXT009="L'&agrave;lbum seleccionat ha sigut eliminat.";
$TEXT010="tamany";
$TEXT011="ha sigut esborrat";
$TEXT012="El directori";
$TEXT013="ha sigut esborrat";
$TEXT014="Totes les entradas de la base de dades relatives a aquesta informaci&oacute; han sigut eliminades";

$TEXT015="La teva not&iacute;cia a sigut emmagatzemada".
         "Si tot es correcte, ser&agrave; publicada per un dels nostres editors tan aviat como sigui possible.";

$TEXT016="L'usuari s'ha creat correctament. Ara ja pots validar-te com usuari registrat";
$TEXT017="La teva petici&oacute; ha sigut processada.";

$TEXT018="Usuari no v&agrave;lid! No pots realitzar aquesta operaci&oacute;.<br>".
         "Potser no hauries d'estar aqu&iacute;!!!<br>".
         "Aquesta situaci&oacute; ha sigut reportada a l'administrador del sistema.";
$TEXT019="Feeds RSS 2.0 actualitzats !";
$TEXT020="Substituit per ->";
$TEXT021="ERROR !<br>El c&oacute;dig introduit no coincideix amb el mostrat.<br>Torni a intentaru una altre vegada.<br><br>";


$SUBMIT_NEW="Enviar";     // IMPORTANT !! Put the same string you putted $TEXT001 in homesite-news 
$SAVE="Guardar";          // IMPORTANT !! Put the same string you putted $TEXT023 in homesite-news
$PREVIEW="Previsualitzar"; // IMPORTANT !! Put the same string you putted $TEXT025 in homesite-news
$PUBLISH="Publicar";      // IMPORTANT !! Put the same string you putted $TEXT026 and $IEBM002 like 
                          // in homesite-news and homesite-info 


?>
